======================
CHANGELOG for Trashman
======================
:Author: Kwpolska
:Copyright: See Appendix A.
:Date: 2012-08-29
:Version: 1.0.2

.. index:: CHANGELOG

1.0.0
=====
:1.0.1: Bugfix release.
:1.0.0: A complete modification of the approach, now using a concept of “backends”, allowing multiple trash systems to be used.

0.2.0
=====
:0.2.4.1 (semi-official): Locale fix #3, only pypi/aur
:0.2.4: Zsh completions.
:0.2.3: Locale fix #2
:0.2.2: Locale fix #1
:0.2.1: Localization support.
:0.2.0: Documentation.  The project became a bit more mature now.

0.1.0
=====
:0.1.3: Fixed some problems with file restoration.
:0.1.2: Ommited a character, also added restoration to --help.
:0.1.1: Restoration magic.
:0.1.0: Initial release.
